@@ -194,7 +194,7 @@ struct poptOption options[] = {
     '\0',
     POPT_ARG_STRING,
     NULL,
-    OPTION_WINDOW_WITH_PROFILE,
+    OPTION_WINDOW_WITH_PROFILE_ID,
     N_("Open a new window containing a tab with the given profile ID. Used internally to save sessions."),
     N_("PROFILEID")
   },
@@ -203,7 +203,7 @@ struct poptOption options[] = {
     '\0',
     POPT_ARG_STRING,
     NULL,
-    OPTION_TAB_WITH_PROFILE,
+    OPTION_TAB_WITH_PROFILE_ID,
     N_("Open a new tab in the last-opened window with the given profile ID. Used internally to save sessions."),
     N_("PROFILEID")
   },
@@ -985,6 +985,7 @@ main (int argc, char **argv)
       return 1;
     }
 
+  terminal_factory_disabled = TRUE; /* FIXME until it works */
   if (!terminal_factory_disabled)
     {
       if (terminal_invoke_factory (results))
@@ -1057,7 +1058,7 @@ main (int argc, char **argv)
             {
               if (it->profile_is_id)
                 profile = terminal_profile_lookup (it->profile);
-              else
+              else                
                 profile = terminal_profile_lookup_by_visible_name (it->profile);
             }
           
@@ -1169,11 +1170,14 @@ terminal_app_new_terminal (TerminalApp     *app,
                            const char      *working_dir)
 {
   TerminalScreen *screen;
-
-  g_return_if_fail (profile);
+  gboolean window_created;
   
+  g_return_if_fail (profile);
+
+  window_created = FALSE;
   if (window == NULL)
     {
+      window_created = TRUE;
       window = terminal_window_new (conf);
       g_object_ref (G_OBJECT (window));
 
@@ -1215,8 +1219,13 @@ terminal_app_new_terminal (TerminalApp     *app,
         g_printerr (_("Invalid geometry string \"%s\"\n"),
                     geometry);
     }
-  
-  gtk_window_present (GTK_WINDOW (window));
+
+  /* don't present on new tab, or we can accidentally make the
+   * terminal jump workspaces.
+   * http://bugzilla.gnome.org/show_bug.cgi?id=78253
+   */
+  if (window_created)
+    gtk_window_present (GTK_WINDOW (window));
 
   terminal_screen_launch_child (screen);
 }
